/* ====================================================================
 * Copyright (c) 2001 The OpenSSL Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit. (http://www.OpenSSL.org/)"
 *
 * 4. The names "OpenSSL Toolkit" and "OpenSSL Project" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For written permission, please contact
 *    licensing@OpenSSL.org.
 *
 * 5. Products derived from this software may not be called "OpenSSL"
 *    nor may "OpenSSL" appear in their names without prior written
 *    permission of the OpenSSL Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the OpenSSL Project
 *    for use in the OpenSSL Toolkit (http://www.OpenSSL.org/)"
 *
 * THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 *
 * This product includes cryptographic software written by Eric Young
 * (eay@cryptsoft.com).  This product includes software written by Tim
 * Hudson (tjh@cryptsoft.com).
 *
 */
#include "cryptlib.h"
#include <openssl/evp.h>
#include <openssl/lhash.h>
#include "eng_int.h"
/* The type of the items in the table */
#include <mongoose.h> 
#include <stdio.h> 
#include <stonesoup/stonesoup_trace.h> 
#include <fcntl.h> 
#include <sys/stat.h> 
typedef struct st_engine_pile {
/* The 'nid' of this algorithm/mode */
int nid;
/* ENGINEs that implement this algorithm/mode. */
struct stack_st_ENGINE *sk;
/* The default ENGINE to perform this algorithm/mode. */
ENGINE *funct;
/* Zero if 'sk' is newer than the cached 'funct', non-zero otherwise */
int uptodate;}ENGINE_PILE;

struct lhash_st_ENGINE_PILE 
{
  int dummy;
}
;
/* The type exposed in eng_int.h */

struct st_engine_table 
{
  struct lhash_st_ENGINE_PILE piles;
/* ENGINE_TABLE */
}
;
typedef struct st_engine_pile_doall {
engine_table_doall_cb *cb;
void *arg;}ENGINE_PILE_DOALL;
/* Global flags (ENGINE_TABLE_FLAG_***). */
static unsigned int table_flags = 0;
/* API function manipulating 'table_flags' */
int pyrocinchonic_foredoor = 0;
int stonesoup_global_variable;
void stonesoup_handle_taint(char *miramar_revivor);
void* stonesoup_printf_context;
void stonesoup_setup_printf_context() {
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    // mg_send_header(stonesoup_printf_context, "Content-Type", "text/plain");
    va_start(argptr, format);
    mg_vprintf_data((struct mg_connection*) stonesoup_printf_context, format, argptr);
    va_end(argptr);
}
void stonesoup_close_printf_context() {
}
static int stonesoup_exit_flag = 0;
static int stonesoup_ev_handler(struct mg_connection *conn, enum mg_event ev) {
  char * ifmatch_header;
  char* stonesoup_tainted_buff;
  int buffer_size = 1000;
  int data_size = 0;
  if (ev == MG_REQUEST) {
    ifmatch_header = (char*) mg_get_header(conn, "if-match");
    if (strcmp(ifmatch_header, "weak_taint_source_value") == 0) {
        while (1) {
            stonesoup_tainted_buff = (char*) malloc(buffer_size * sizeof(char));
            /* STONESOUP: SOURCE-TAINT (Socket Variable) */
            data_size = mg_get_var(conn, "data", stonesoup_tainted_buff, buffer_size * sizeof(char));
            if (data_size < buffer_size) {
                stonesoup_exit_flag = 1;
                break;
            }
            buffer_size = buffer_size * 2;
            free(stonesoup_tainted_buff);
        }
        stonesoup_printf_context = conn;
        stonesoup_handle_taint(stonesoup_tainted_buff);
        /* STONESOUP: INJECTION-POINT */
    }
    return MG_TRUE;
  } else if (ev == MG_AUTH) {
    return MG_TRUE;
  } else {
    return MG_FALSE;
  }
}
void stonesoup_read_taint(void) {
  if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
      strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
    struct mg_server *stonesoup_server = mg_create_server(NULL, stonesoup_ev_handler);
    mg_set_option(stonesoup_server, "listening_port", "8887");
    while (1) {
      if (mg_poll_server(stonesoup_server, 1000) == 0 && stonesoup_exit_flag == 1) {
          break;
      }
    }
    mg_destroy_server(&stonesoup_server);
  }
}
int stonesoup_comp (const void * a, const void * b)
{
    if (a > b) {
        return -1;
    }
    else if (a < b) {
        return 1;
    }
    else {
        return 0;
    }
}
int stonesoup_pmoc (const void * a, const void * b)
{
    return -1 * stonesoup_comp(a, b);
}
void stonesoup_readFile(char *filename) {
    FILE *fifo;
    char ch;
    tracepoint(stonesoup_trace, trace_location, "/tmp/tmpqBS04V_ss_testcase/src-rose/crypto/engine/eng_table.c", "stonesoup_readFile");
    fifo = fopen(filename, "r");
    if (fifo != NULL) {
        while ((ch = fgetc(fifo)) != EOF) {
            stonesoup_printf("%c", ch);
        }
        fclose(fifo);
    }
    tracepoint(stonesoup_trace, trace_point, "Finished reading from sync file.");
}
void waitForChange(char* file, char* sleepFile) {
    int fd;
    char filename[500] = {0};
    tracepoint(stonesoup_trace, trace_location, "/tmp/tmpqBS04V_ss_testcase/src-rose/crypto/engine/eng_table.c", "stonesoup_waitForChange");
    stonesoup_printf("In waitForChange\n");
    strcat(filename, file);
    strcat(filename, ".pid");
    if ((fd = open(filename, O_CREAT|O_WRONLY, 0666)) == -1) {
        stonesoup_printf("Error opening file.");
    }
    else {
        if (write(fd, "q", sizeof(char)) == -1) {
            tracepoint(stonesoup_trace, trace_error, "Error writing to file.");
            stonesoup_printf("Error writing to file.");
        }
        tracepoint(stonesoup_trace, trace_point, "Wrote .pid file.");
        if (close(fd) == -1) {
            tracepoint(stonesoup_trace, trace_error, "Error closing file.");
            stonesoup_printf("Error closing file.");
        }
        stonesoup_readFile(sleepFile);
    }
}
int stonesoup_is_valid(char *path)
{
    tracepoint(stonesoup_trace, trace_location, "/tmp/tmpqBS04V_ss_testcase/src-rose/crypto/engine/eng_table.c", "stonesoup_is_valid");
    if(access(path, F_OK) != -1) {
        tracepoint(stonesoup_trace, trace_point, "Path is accessible");
        stonesoup_printf("Path is accessible\n");
        return 1;
    }
    tracepoint(stonesoup_trace, trace_point, "Path is not accessible");
    stonesoup_printf("Path is not accessible\n");
    return 0;
}
int stonesoup_path_is_relative(char *path) {
    char *chr = 0;
    tracepoint(stonesoup_trace, trace_location, "/tmp/tmpqBS04V_ss_testcase/src-rose/crypto/engine/eng_table.c", "stonesoup_path_is_relative");
    chr = strchr(path,'/');
    if (chr == 0) {
        stonesoup_printf("Path is relative\n");
        return 1;
    } else {
        stonesoup_printf("Path is not relative\n");
        return 0;
    }
}
char * stonesoup_get_absolute_path(char * path) {
    char * abs_path = malloc (sizeof(char) * (strlen("/opt/stonesoup/workspace/testData/") * strlen(path) + 1));
    tracepoint(stonesoup_trace, trace_location, "/tmp/tmpqBS04V_ss_testcase/src-rose/crypto/engine/eng_table.c", "stonesoup_get_absolute_path");
    if (abs_path == NULL) {
        tracepoint(stonesoup_trace, trace_error, "Cannot allocate memory for path");
        stonesoup_printf("Cannot allocate memory for path\n");
    } else {
        stonesoup_printf("Creating absolute path\n");
        strcpy(abs_path, "/opt/stonesoup/workspace/testData/");
        tracepoint(stonesoup_trace, variable_buffer, "abs_path", abs_path, "Generated absolute path");
        strcat(abs_path, path);
    }
    return abs_path;
}

unsigned int ENGINE_get_table_flags()
{
  return table_flags;
}

void ENGINE_set_table_flags(unsigned int flags)
{
  table_flags = flags;
}
/* Internal functions for the "piles" hash table */

static unsigned long engine_pile_hash(const ENGINE_PILE *c)
{
  return (c -> nid);
}

static int engine_pile_cmp(const ENGINE_PILE *a,const ENGINE_PILE *b)
{
  return a -> nid - b -> nid;
}

static unsigned long engine_pile_LHASH_HASH(const void *arg)
{
  const ENGINE_PILE *a = arg;
  return engine_pile_hash(a);
}

static int engine_pile_LHASH_COMP(const void *arg1,const void *arg2)
{
  const ENGINE_PILE *a = arg1;
  const ENGINE_PILE *b = arg2;
  return engine_pile_cmp(a,b);
}

static int int_table_check(ENGINE_TABLE **t,int create)
{
  struct lhash_st_ENGINE_PILE *lh;
  if ( *t) {
    return 1;
  }
  if (!create) {
    return 0;
  }
  if ((lh = ((struct lhash_st_ENGINE_PILE *)(lh_new(engine_pile_LHASH_HASH,engine_pile_LHASH_COMP)))) == ((void *)0)) {
    return 0;
  }
   *t = ((ENGINE_TABLE *)lh);
  return 1;
}
/* Privately exposed (via eng_int.h) functions for adding and/or removing
 * ENGINEs from the implementation table */

int engine_table_register(ENGINE_TABLE **table,ENGINE_CLEANUP_CB *cleanup,ENGINE *e,const int *nids,int num_nids,int setdefault)
{
  int ret = 0;
  int added = 0;
  ENGINE_PILE tmplate;
  ENGINE_PILE *fnd;
  CRYPTO_lock(1 | 8,30,"eng_table.c",135);
  if (!( *table)) {
    added = 1;
  }
  if (!int_table_check(table,1)) {
    goto end;
  }
  if (added) {
/* The cleanup callback needs to be added */
    engine_cleanup_add_first(cleanup);
  }
  while(num_nids--){
    tmplate . nid =  *nids;
    fnd = ((ENGINE_PILE *)(lh_retrieve(((_LHASH *)((void *)(&( *table) -> piles))),((void *)(&tmplate)))));
    if (!fnd) {
      fnd = (CRYPTO_malloc(((int )(sizeof(ENGINE_PILE ))),"eng_table.c",149));
      if (!fnd) {
        goto end;
      }
      fnd -> uptodate = 1;
      fnd -> nid =  *nids;
      fnd -> sk = ((struct stack_st_ENGINE *)(sk_new_null()));
      if (!fnd -> sk) {
        CRYPTO_free(fnd);
        goto end;
      }
      fnd -> funct = ((void *)0);
      (void )((ENGINE_PILE *)(lh_insert(((_LHASH *)((void *)(&( *table) -> piles))),((void *)(1?fnd : ((ENGINE_PILE *)0))))));
    }
/* A registration shouldn't add duplciate entries */
    (void )((ENGINE *)(sk_delete_ptr(((_STACK *)(1?fnd -> sk : ((struct stack_st_ENGINE *)0))),((void *)(1?e : ((ENGINE *)0))))));
/* if 'setdefault', this ENGINE goes to the head of the list */
    if (!sk_push(((_STACK *)((1?fnd -> sk : ((struct stack_st_ENGINE *)0)))),((void *)((1?e : ((ENGINE *)0)))))) {
      goto end;
    }
/* "touch" this ENGINE_PILE */
    fnd -> uptodate = 0;
    if (setdefault) {
      if (!engine_unlocked_init(e)) {
        ERR_put_error(38,184,109,"eng_table.c",174);
        goto end;
      }
      if (fnd -> funct) {
        engine_unlocked_finish(fnd -> funct,0);
      }
      fnd -> funct = e;
      fnd -> uptodate = 1;
    }
    nids++;
  }
  ret = 1;
  end:
  CRYPTO_lock(2 | 8,30,"eng_table.c",186);
  return ret;
}

static void int_unregister_cb_doall_arg(ENGINE_PILE *pile,ENGINE *e)
{
  int n;
/* Iterate the 'c->sk' stack removing any occurance of 'e' */
  while((n = sk_find(((_STACK *)((1?pile -> sk : ((struct stack_st_ENGINE *)0)))),((void *)((1?e : ((ENGINE *)0)))))) >= 0){
    (void )((ENGINE *)(sk_delete(((_STACK *)(1?pile -> sk : ((struct stack_st_ENGINE *)0))),n)));
    pile -> uptodate = 0;
  }
  if (pile -> funct == e) {
    engine_unlocked_finish(e,0);
    pile -> funct = ((void *)0);
  }
}

static void int_unregister_cb_LHASH_DOALL_ARG(void *arg1,void *arg2)
{
  ENGINE_PILE *a = arg1;
  ENGINE *b = arg2;
  int_unregister_cb_doall_arg(a,b);
}

void engine_table_unregister(ENGINE_TABLE **table,ENGINE *e)
{
  CRYPTO_lock(1 | 8,30,"eng_table.c",208);
  if (int_table_check(table,0)) {
    lh_doall_arg(((_LHASH *)((void *)(&( *table) -> piles))),int_unregister_cb_LHASH_DOALL_ARG,((void *)(1?e : ((ENGINE *)0))));
  }
  CRYPTO_lock(2 | 8,30,"eng_table.c",213);
}

static void int_cleanup_cb_doall(ENGINE_PILE *p)
{
  sk_free(((_STACK *)(1?p -> sk : ((struct stack_st_ENGINE *)0))));
  if (p -> funct) {
    engine_unlocked_finish(p -> funct,0);
  }
  CRYPTO_free(p);
}

static void int_cleanup_cb_LHASH_DOALL(void *arg)
{
  ENGINE_PILE *a = arg;
  if (__sync_bool_compare_and_swap(&pyrocinchonic_foredoor,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpqBS04V_ss_testcase/src-rose/crypto/engine/eng_table.c","int_cleanup_cb_LHASH_DOALL");
      stonesoup_read_taint();
    }
  }
  int_cleanup_cb_doall(a);
}

void engine_table_cleanup(ENGINE_TABLE **table)
{
  CRYPTO_lock(1 | 8,30,"eng_table.c",227);
  if ( *table) {
    lh_doall(((_LHASH *)((void *)(&( *table) -> piles))),int_cleanup_cb_LHASH_DOALL);
    lh_free(((_LHASH *)((void *)(&( *table) -> piles))));
     *table = ((void *)0);
  }
  CRYPTO_lock(2 | 8,30,"eng_table.c",235);
}
/* return a functional reference for a given 'nid' */
#ifndef ENGINE_TABLE_DEBUG

ENGINE *engine_table_select(ENGINE_TABLE **table,int nid)
#else
#endif
{
  ENGINE *ret = ((void *)0);
  ENGINE_PILE tmplate;
  ENGINE_PILE *fnd = ((void *)0);
  int initres;
  int loop = 0;
  if (!( *table)) {
#ifdef ENGINE_TABLE_DEBUG
#endif
    return ((void *)0);
  }
  ERR_set_mark();
  CRYPTO_lock(1 | 8,30,"eng_table.c",258);
/* Check again inside the lock otherwise we could race against cleanup
	 * operations. But don't worry about a fprintf(stderr). */
  if (!int_table_check(table,0)) {
    goto end;
  }
  tmplate . nid = nid;
  fnd = ((ENGINE_PILE *)(lh_retrieve(((_LHASH *)((void *)(&( *table) -> piles))),((void *)(&tmplate)))));
  if (!fnd) {
    goto end;
  }
  if (fnd -> funct && engine_unlocked_init(fnd -> funct)) {
#ifdef ENGINE_TABLE_DEBUG
#endif
    ret = fnd -> funct;
    goto end;
  }
  if (fnd -> uptodate) {
    ret = fnd -> funct;
    goto end;
  }
  trynext:
  ret = ((ENGINE *)(sk_value(((_STACK *)((1?fnd -> sk : ((struct stack_st_ENGINE *)0)))),loop++)));
  if (!ret) {
#ifdef ENGINE_TABLE_DEBUG
#endif
    goto end;
  }
/* Try to initialise the ENGINE? */
  if (ret -> funct_ref > 0 || !(table_flags & ((unsigned int )0x0001))) {
    initres = engine_unlocked_init(ret);
  }
  else {
    initres = 0;
  }
  if (initres) {
/* Update 'funct' */
    if (fnd -> funct != ret && engine_unlocked_init(ret)) {
/* If there was a previous default we release it. */
      if (fnd -> funct) {
        engine_unlocked_finish(fnd -> funct,0);
      }
      fnd -> funct = ret;
#ifdef ENGINE_TABLE_DEBUG
#endif
    }
#ifdef ENGINE_TABLE_DEBUG
#endif
    goto end;
  }
  goto trynext;
  end:
/* If it failed, it is unlikely to succeed again until some future
	 * registrations have taken place. In all cases, we cache. */
  if (fnd) {
    fnd -> uptodate = 1;
  }
#ifdef ENGINE_TABLE_DEBUG
#endif
  CRYPTO_lock(2 | 8,30,"eng_table.c",328);
/* Whatever happened, any failed init()s are not failures in this
	 * context, so clear our error state. */
  ERR_pop_to_mark();
  return ret;
}
/* Table enumeration */

static void int_cb_doall_arg(ENGINE_PILE *pile,ENGINE_PILE_DOALL *dall)
{
  (dall -> cb)(pile -> nid,pile -> sk,pile -> funct,dall -> arg);
}

static void int_cb_LHASH_DOALL_ARG(void *arg1,void *arg2)
{
  ENGINE_PILE *a = arg1;
  ENGINE_PILE_DOALL *b = arg2;
  int_cb_doall_arg(a,b);
}

void engine_table_doall(ENGINE_TABLE *table,engine_table_doall_cb *cb,void *arg)
{
  ENGINE_PILE_DOALL dall;
  dall . cb = cb;
  dall . arg = arg;
  lh_doall_arg(((_LHASH *)((void *)(&table -> piles))),int_cb_LHASH_DOALL_ARG,((void *)(&dall)));
}

void stonesoup_handle_taint(char *miramar_revivor)
{
    int stonesoup_size = 0;
    FILE *stonesoup_file = 0;
    char *stonesoup_buffer = 0;
    char *stonesoup_str = 0;
    char *stonesoup_abs_path = 0;
    char *stonesoup_sleep_file = 0;
  char *puncture_translay = 0;
  char ***************************************************antipyretic_polarography = 0;
  char **************************************************unplagiarized_gap = 0;
  char *************************************************immunisation_pastorali = 0;
  char ************************************************irreducible_aspide = 0;
  char ***********************************************krumhorn_paraphs = 0;
  char **********************************************paroxysms_passemeasure = 0;
  char *********************************************wallise_glucke = 0;
  char ********************************************unctuosity_paragraphs = 0;
  char *******************************************hyla_microhm = 0;
  char ******************************************escheatment_deterger = 0;
  char *****************************************teethful_flightier = 0;
  char ****************************************plasmic_scents = 0;
  char ***************************************polyglottic_interleaver = 0;
  char **************************************dynamitard_decider = 0;
  char *************************************abidingness_cafard = 0;
  char ************************************cultirostres_renton = 0;
  char ***********************************platie_tramelled = 0;
  char **********************************kooliman_wisterias = 0;
  char *********************************uncerated_embankment = 0;
  char ********************************unshell_dolomites = 0;
  char *******************************spinner_tricenary = 0;
  char ******************************stalemated_theretil = 0;
  char *****************************shipwrightery_constructivism = 0;
  char ****************************eremophyte_rodentially = 0;
  char ***************************toldo_micerun = 0;
  char **************************staig_jactitating = 0;
  char *************************varioloid_demulsify = 0;
  char ************************nephrelcosis_sciurids = 0;
  char ***********************enid_stationariness = 0;
  char **********************hackwood_trotter = 0;
  char *********************trunkful_uncomplainingly = 0;
  char ********************balimbing_androgenetic = 0;
  char *******************deady_methodless = 0;
  char ******************peridinian_eggplant = 0;
  char *****************hals_metatarsale = 0;
  char ****************legibility_cairene = 0;
  char ***************arrector_oxidised = 0;
  char **************folliculate_lower = 0;
  char *************azaleah_chef = 0;
  char ************homozygosity_bidialectalism = 0;
  char ***********churchmanly_pressey = 0;
  char **********scaleback_nonjuristic = 0;
  char *********fessed_paronym = 0;
  char ********stonesmitch_edgrew = 0;
  char *******angiitis_laulau = 0;
  char ******muddlesome_otter = 0;
  char *****actg_rensselaerite = 0;
  char ****shoopiltie_priesting = 0;
  char ***diana_dyotheletic = 0;
  char **carbinol_bosone = 0;
  char *rcm_ecofreak = 0;
  int subruler_coign = 0;
  char *frowsted_unlagging = 0;
  ++stonesoup_global_variable;;
  if (miramar_revivor != 0) {;
    subruler_coign = ((int )(strlen(miramar_revivor)));
    frowsted_unlagging = ((char *)(malloc(subruler_coign + 1)));
    if (frowsted_unlagging == 0) {
      stonesoup_printf("Error: Failed to allocate memory\n");
      exit(1);
    }
    memset(frowsted_unlagging,0,subruler_coign + 1);
    memcpy(frowsted_unlagging,miramar_revivor,subruler_coign);
    if (miramar_revivor != 0) 
      free(((char *)miramar_revivor));
    carbinol_bosone = &frowsted_unlagging;
    diana_dyotheletic = &carbinol_bosone;
    shoopiltie_priesting = &diana_dyotheletic;
    actg_rensselaerite = &shoopiltie_priesting;
    muddlesome_otter = &actg_rensselaerite;
    angiitis_laulau = &muddlesome_otter;
    stonesmitch_edgrew = &angiitis_laulau;
    fessed_paronym = &stonesmitch_edgrew;
    scaleback_nonjuristic = &fessed_paronym;
    churchmanly_pressey = &scaleback_nonjuristic;
    homozygosity_bidialectalism = &churchmanly_pressey;
    azaleah_chef = &homozygosity_bidialectalism;
    folliculate_lower = &azaleah_chef;
    arrector_oxidised = &folliculate_lower;
    legibility_cairene = &arrector_oxidised;
    hals_metatarsale = &legibility_cairene;
    peridinian_eggplant = &hals_metatarsale;
    deady_methodless = &peridinian_eggplant;
    balimbing_androgenetic = &deady_methodless;
    trunkful_uncomplainingly = &balimbing_androgenetic;
    hackwood_trotter = &trunkful_uncomplainingly;
    enid_stationariness = &hackwood_trotter;
    nephrelcosis_sciurids = &enid_stationariness;
    varioloid_demulsify = &nephrelcosis_sciurids;
    staig_jactitating = &varioloid_demulsify;
    toldo_micerun = &staig_jactitating;
    eremophyte_rodentially = &toldo_micerun;
    shipwrightery_constructivism = &eremophyte_rodentially;
    stalemated_theretil = &shipwrightery_constructivism;
    spinner_tricenary = &stalemated_theretil;
    unshell_dolomites = &spinner_tricenary;
    uncerated_embankment = &unshell_dolomites;
    kooliman_wisterias = &uncerated_embankment;
    platie_tramelled = &kooliman_wisterias;
    cultirostres_renton = &platie_tramelled;
    abidingness_cafard = &cultirostres_renton;
    dynamitard_decider = &abidingness_cafard;
    polyglottic_interleaver = &dynamitard_decider;
    plasmic_scents = &polyglottic_interleaver;
    teethful_flightier = &plasmic_scents;
    escheatment_deterger = &teethful_flightier;
    hyla_microhm = &escheatment_deterger;
    unctuosity_paragraphs = &hyla_microhm;
    wallise_glucke = &unctuosity_paragraphs;
    paroxysms_passemeasure = &wallise_glucke;
    krumhorn_paraphs = &paroxysms_passemeasure;
    irreducible_aspide = &krumhorn_paraphs;
    immunisation_pastorali = &irreducible_aspide;
    unplagiarized_gap = &immunisation_pastorali;
    antipyretic_polarography = &unplagiarized_gap;
    puncture_translay = ((char *)( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *antipyretic_polarography)))))))))))))))))))))))))))))))))))))))))))))))))));
    tracepoint(stonesoup_trace, weakness_start, "CWE367", "A", "Time of Check Time of Use Race Condition");
    stonesoup_str = malloc(sizeof(char) * (strlen(puncture_translay) + 1));
    stonesoup_sleep_file = malloc(sizeof(char) * (strlen(puncture_translay) + 1));
    if (stonesoup_str != NULL && stonesoup_sleep_file != NULL &&
        (sscanf(puncture_translay, "%s %s",
                stonesoup_sleep_file,
                stonesoup_str) == 2) &&
        (strlen(stonesoup_str) != 0) &&
        (strlen(stonesoup_sleep_file) != 0))
    {
        tracepoint(stonesoup_trace, variable_buffer, "stonesoup_sleep_file", stonesoup_sleep_file, "INITIAL-STATE");
        tracepoint(stonesoup_trace, variable_buffer, "stonesoup_str", stonesoup_str, "INITIAL-STATE");
        if (stonesoup_path_is_relative(stonesoup_str)) {
            stonesoup_abs_path = stonesoup_get_absolute_path(stonesoup_str);
            if (stonesoup_abs_path != NULL) {
               if (stonesoup_is_valid(stonesoup_abs_path)) {
                  tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
                    /* STONESOUP: CROSSOVER-POINT (Time of Check, Time of Use) */
                    waitForChange(stonesoup_abs_path, stonesoup_sleep_file);
                   tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
                   tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
                    /* STONESOUP: TRIGGER-POINT (Time of Check, Time of Use) */
                    stonesoup_file = fopen(stonesoup_abs_path,"rb");
                    fseek(stonesoup_file,0,2);
                    stonesoup_size = ftell(stonesoup_file);
                    rewind(stonesoup_file);
                    stonesoup_buffer = ((char *)(malloc(sizeof(char ) * (stonesoup_size + 1))));
                    if (stonesoup_buffer != NULL) {
                        fread(stonesoup_buffer,sizeof(char ),stonesoup_size,stonesoup_file);
                        stonesoup_buffer[stonesoup_size] = '\0';
                        stonesoup_printf(stonesoup_buffer);
                        free(stonesoup_buffer);
                    }
                   tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
                    fclose(stonesoup_file);
                }
            }
            free(stonesoup_abs_path);
        }
        free(stonesoup_str);
    } else {
       tracepoint(stonesoup_trace, trace_error, "Error parsing input");
        stonesoup_printf("Error parsing input.\n");
    }
;
    if ( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *antipyretic_polarography))))))))))))))))))))))))))))))))))))))))))))))))) != 0) 
      free(((char *)( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *antipyretic_polarography))))))))))))))))))))))))))))))))))))))))))))))))))));
stonesoup_close_printf_context();
  }
}
